@@ -19,9 +19,9 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.1 $
- * @(#) $Id: str.c,v 30.1 2007/03/16 11:09:46 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/str.c,v $
+ * @(#) $Revision: 30.5 $
+ * @(#) $Id: str.c,v 30.5 2013/09/02 01:38:08 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/str.c,v $
  *
  * Under source code control:	1990/02/15 01:48:10
  * File existed as early as:	before 1990
@@ -31,6 +31,7 @@
 
 
 #include <stdio.h>
+#include <ctype.h>
 #include "calc.h"
 #include "str.h"
 
@@ -162,7 +163,8 @@ findstr(STRINGHEAD *hp, char *str)
 	index = 0;
 	while (*test) {
 		testlen = strlen(test);
-		if ((testlen == len) && (*test == *str) && (strcmp(test, str) == 0))
+		if ((testlen == len) && (*test == *str) &&
+		    (strcmp(test, str) == 0))
 			return index;
 		test += (testlen + 1);
 		index++;
@@ -263,7 +265,8 @@ addliteral(char *str)
 	if (literals.l_count >= literals.l_maxcount) {
 		count = literals.l_maxcount + STR_TABLECHUNK;
 		if (literals.l_maxcount)
-			table = (char **) realloc(literals.l_table, count * sizeof(char *));
+			table = (char **) realloc(literals.l_table, count *
+						  sizeof(char *));
 		else
 			table = (char **) malloc(count * sizeof(char *));
 		if (table == NULL) {
@@ -680,6 +683,47 @@ stringshift(STRING *s1, long n)
 	return s;
 }
 
+/*
+ * stringtoupper makes st upper case
+ */
+STRING *
+stringtoupper(STRING *st)
+{
+        char *c1, *c2;
+        size_t num;
+
+        if (st->s_len > 0) {
+                c1 = st->s_str;
+                num = st->s_len;
+                c2 = c1;
+                while (num-- > 0)
+                        *c1++ = (char)toupper((int)*c2++);
+                *c1 = '\0';
+        }
+        return slink(st);
+}
+
+/*
+ * stringtolower makes st lower case
+ */
+STRING *
+stringtolower(STRING *st)
+{
+        char *c1, *c2;
+        size_t num;
+
+        if (st->s_len > 0) {
+                c1 = st->s_str;
+                num = st->s_len;
+                c2 = c1;
+                while (num-- > 0)
+                        *c1++ = (char)tolower((int)*c2++);
+                *c1 = '\0';
+        }
+        return slink(st);
+}
+
+
 /*
  * stringcpy copies as many characters as possible
  * from s2 to s1 and returns s1
@@ -850,7 +894,43 @@ stringrel(STRING *s1, STRING *s2)
 	return (i1 > i2);
 }
 
+/* Case independent stringrel(STRING *s1, STRING *s2)
+ * stringcaserel returns 0 if strings are equal; otherwise 1 or -1 according
+ * as the greater of the first unequal characters are in the first or
+ * second string, or in the case of unequal-length strings when the compared
+ * characters are all equal, 1 or -1 according as the first or second string
+ * is longer.
+ */
+FLAG
+stringcaserel(STRING *s1, STRING *s2)
+{
+	char *c1, *c2;
+	long i1, i2;
 
+	if (s1 == s2)
+		return 0;
+
+	i1 = s1->s_len;
+	i2 = s2->s_len;
+	if (i2 == 0)
+		return (i1 > 0);
+	if (i1 == 0)
+		return -1;
+	c1 = s1->s_str;
+	c2 = s2->s_str;
+	while (i1 > 1 && i2 > 1 && tolower(*c1) == tolower(*c2)) {
+		i1--;
+		i2--;
+		c1++;
+		c2++;
+	}
+	if ( (tolower(*c1)) > (tolower(*c2)))
+        	return 1;
+	if ( (tolower(*c1)) <  (tolower(*c2)))
+        	return -1;
+	if (i1 < i2) return -1;
+	return (i1 > i2);
+}
 /*
  * str with characters c0, c1, ... is considered as a bitstream, 8 bits
  * per character; within a character the bits ordered from low order to
@@ -1214,7 +1294,8 @@ addstring(char *str, size_t len)
 			sp = (STRING **) realloc((char *) stringconsttable,
 			sizeof(STRING *) * (stringconstcount + STRCONSTALLOC));
 			if (sp == NULL) {
-				math_error("Unable to reallocate string const table");
+				math_error("Unable to reallocate string "
+					   "const table");
 				/*NOTREACHED*/
 			}
 			stringconsttable = sp;
