@@ -1,7 +1,7 @@
 /*
  * value - definitions of general values  and related routines used by calc
  *
- * Copyright (C) 1999-2007  David I. Bell
+ * Copyright (C) 1999-2007,2014  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,9 +17,9 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.3 $
- * @(#) $Id: value.h,v 30.3 2007/07/10 21:18:08 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/value.h,v $
+ * @(#) $Revision: 30.8 $
+ * @(#) $Id: value.h,v 30.8 2014/08/24 21:56:51 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/value.h,v $
  *
  * Under source code control:	1993/07/30 19:42:47
  * File existed as early as:	1993
@@ -28,8 +28,8 @@
  */
 
 
-#if !defined(__VALUE_H__)
-#define __VALUE_H__
+#if !defined(INCLUDE_VALUE_H)
+#define INCLUDE_VALUE_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
@@ -297,7 +297,8 @@ E_FUNC BOOL mattest(MATRIX *m);
 E_FUNC void matsum(MATRIX *m, VALUE *vres);
 E_FUNC BOOL matcmp(MATRIX *m1, MATRIX *m2);
 E_FUNC int matsearch(MATRIX *m, VALUE *vp, long start, long end, ZVALUE *index);
-E_FUNC int matrsearch(MATRIX *m, VALUE *vp, long start, long end, ZVALUE *index);
+E_FUNC int matrsearch(MATRIX *m, VALUE *vp, long start, long end,
+		      ZVALUE *index);
 E_FUNC VALUE matdet(MATRIX *m);
 E_FUNC VALUE matdot(MATRIX *m1, MATRIX *m2);
 E_FUNC void matfill(MATRIX *m, VALUE *v1, VALUE *v2);
@@ -344,7 +345,8 @@ E_FUNC void removelistmiddle(LIST *lp, long index, VALUE *vp);
 E_FUNC void listfree(LIST *lp);
 E_FUNC void listprint(LIST *lp, long max_print);
 E_FUNC int listsearch(LIST *lp, VALUE *vp, long start, long end, ZVALUE *index);
-E_FUNC int listrsearch(LIST *lp, VALUE *vp, long start, long end, ZVALUE *index);
+E_FUNC int listrsearch(LIST *lp, VALUE *vp, long start, long end,
+		       ZVALUE *index);
 E_FUNC BOOL listcmp(LIST *lp1, LIST *lp2);
 E_FUNC VALUE *listfindex(LIST *lp, long index);
 E_FUNC LIST *listalloc(void);
@@ -389,8 +391,10 @@ E_FUNC ASSOC *assocalloc(long initsize);
 E_FUNC ASSOC *assoccopy(ASSOC *ap);
 E_FUNC void assocfree(ASSOC *ap);
 E_FUNC void assocprint(ASSOC *ap, long max_print);
-E_FUNC int assocsearch(ASSOC *ap, VALUE *vp, long start, long end, ZVALUE *index);
-E_FUNC int assocrsearch(ASSOC *ap, VALUE *vp, long start, long end, ZVALUE *index);
+E_FUNC int assocsearch(ASSOC *ap, VALUE *vp, long start, long end,
+		       ZVALUE *index);
+E_FUNC int assocrsearch(ASSOC *ap, VALUE *vp, long start, long end,
+			ZVALUE *index);
 E_FUNC BOOL assoccmp(ASSOC *ap1, ASSOC *ap2);
 E_FUNC VALUE *assocfindex(ASSOC *ap, long index);
 E_FUNC VALUE *associndex(ASSOC *ap, BOOL create, long dim, VALUE *indices);
@@ -520,6 +524,8 @@ E_FUNC STRING *stringsegment(STRING *, long, long);
 E_FUNC STRING *stringshift(STRING *, long);
 E_FUNC STRING *stringcomp(STRING *);
 E_FUNC STRING *stringneg(STRING *);
+E_FUNC STRING *stringtolower(STRING *);
+E_FUNC STRING *stringtoupper(STRING *);
 E_FUNC STRING *stringcpy(STRING *, STRING *);
 E_FUNC STRING *stringncpy(STRING *, STRING *, size_t);
 E_FUNC long stringcontent(STRING *s);
@@ -527,10 +533,11 @@ E_FUNC long stringlowbit(STRING *s);
 E_FUNC long stringhighbit(STRING *s);
 E_FUNC BOOL stringcmp(STRING *, STRING *);
 E_FUNC BOOL stringrel(STRING *, STRING *);
+E_FUNC BOOL stringcaserel(STRING *, STRING *);
 E_FUNC int stringbit(STRING *, long);
 E_FUNC BOOL stringtest(STRING *);
 E_FUNC int stringsetbit(STRING *, long, BOOL);
 E_FUNC int stringsearch(STRING *, STRING *, long, long, ZVALUE *);
 E_FUNC int stringrsearch(STRING *, STRING *, long, long, ZVALUE *);
 
-#endif /* !__VALUE_H__ */
+#endif /* !INCLUDE_VALUE_H */
