@@ -1,7 +1,7 @@
 /*
  * zmath - declarations for extended precision integer arithmetic
  *
- * Copyright (C) 1999-2007  David I. Bell
+ * Copyright (C) 1999-2007,2014  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,9 +17,9 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.2 $
- * @(#) $Id: zmath.h,v 30.2 2007/07/05 13:30:38 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/zmath.h,v $
+ * @(#) $Revision: 30.6 $
+ * @(#) $Id: zmath.h,v 30.6 2014/09/30 00:55:11 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/zmath.h,v $
  *
  * Under source code control:	1993/07/30 19:42:48
  * File existed as early as:	1993
@@ -34,8 +34,8 @@
  */
 
 
-#if !defined(__ZMATH_H__)
-#define __ZMATH_H__
+#if !defined(INCLUDE_ZMATH_H)
+#define INCLUDE_ZMATH_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
@@ -180,12 +180,12 @@ typedef SB32 LEN;			/* unit of length storage */
 
 
 /*
- * FNV-1 basis
+ * Quickhash basis
  *
  * We start the hash at a non-zero value at the beginning so that
  * hashing blocks of data with all 0 bits do not map onto the same
- * 0 hash value.  The virgin value that we use below is the hash value
- * that we would get from following 32 ASCII characters:
+ * 0 hash value.  The virgin value that we use below is the 32-bit
+ * FNV-0 hash value that we would get from following 32 ASCII characters:
  *
  *		chongo <Landon Curt Noll> /\../\
  *
@@ -213,7 +213,7 @@ typedef SB32 LEN;			/* unit of length storage */
  * to be a cryptographic hash function, just a fast and reasonably
  * good hash function.
  */
-#define FNV1_32_BASIS ((QCKHASH)(0x811c9dc5))
+#define QUICKHASH_BASIS ((QCKHASH)(0x811c9dc5))
 
 
 /*
@@ -376,8 +376,10 @@ E_FUNC FULL zpprime(ZVALUE z);
 E_FUNC void zpfact(ZVALUE z, ZVALUE *dest);
 E_FUNC BOOL zprimetest(ZVALUE z, long count, ZVALUE skip);
 E_FUNC BOOL zredcprimetest(ZVALUE z, long count, ZVALUE skip);
-E_FUNC BOOL znextcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res, ZVALUE mod, ZVALUE *cand);
-E_FUNC BOOL zprevcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res, ZVALUE mod, ZVALUE *cand);
+E_FUNC BOOL znextcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res,
+		      ZVALUE mod, ZVALUE *cand);
+E_FUNC BOOL zprevcand(ZVALUE z1, long count, ZVALUE skip, ZVALUE res,
+		      ZVALUE mod, ZVALUE *cand);
 E_FUNC FULL zlowfactor(ZVALUE z, long count);
 E_FUNC FLAG zfactor(ZVALUE z1, ZVALUE z2, ZVALUE *res);
 E_FUNC long zpix(ZVALUE z1);
@@ -447,7 +449,8 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
 /*
  * zgtmaxfull(z)	TRUE if abs(z) > MAXFULL
  */
-#define zgtmaxfull(z)	(((z).len > 2) || (((z).len == 2) && (((SHALF)(z).v[1]) < 0)))
+#define zgtmaxfull(z)	(((z).len > 2) || (((z).len == 2) && \
+			 (((SHALF)(z).v[1]) < 0)))
 
 /*
  * zgtmaxufull(z)	TRUE if abs(z) will not fit into a FULL (> MAXUFULL)
@@ -467,7 +470,8 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
  * zgtmaxlong(z)	TRUE if abs(z) > MAXLONG
  */
 #if BASEB >= LONG_BITS
-#define zgtmaxlong(z)	(((z).len > 1) || (((z).len == 1) && (((SHALF)(z).v[0]) < 0)))
+#define zgtmaxlong(z)	(((z).len > 1) || (((z).len == 1) && \
+			 (((SHALF)(z).v[0]) < 0)))
 #else
 #define zgtmaxlong(z)	zgtmaxfull(z)
 #endif
@@ -510,8 +514,10 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
 #else
 
 #define zge16b(z)	(!zistiny(z))
-#define zge24b(z)	(((z).len > 2) || (((z).len == 2) && ((z).v[1] >= (HALF)0x100)))
-#define zge31b(z)	(((z).len > 2) || (((z).len == 2) && (((SHALF)(z).v[1]) < 0)))
+#define zge24b(z)	(((z).len > 2) || (((z).len == 2) && \
+			 ((z).v[1] >= (HALF)0x100)))
+#define zge31b(z)	(((z).len > 2) || (((z).len == 2) && \
+			 (((SHALF)(z).v[1]) < 0)))
 #define zge32b(z)	((z).len > 2)
 #define zge64b(z)	((z).len > 4)
 #define zge128b(z)	((z).len > 8)
@@ -663,4 +669,4 @@ typedef struct {
 } BITSTR;
 
 
-#endif /* !__ZMATH_H__*/
+#endif /* !INCLUDE_ZMATH_H*/
